ete2.treeview.faces.ProfileFace

Package ete2 :: Package treeview :: Module faces :: Class ProfileFace |
[hide private]
[frames] | no frames]

# Class ProfileFace

source code

    object --+
             |
          Face --+
                 |
                ProfileFace

    Creates a new vector profile face object.

    Arguments description
    ---------------------

    max_v:    maximum value used to build the build the plot scale.
    max_v:    manimum value used to build the build the plot scale.
    center_v: Center value used to scale plot and heat map.
    width:    Plot width in pixels. (defaulf=200)
    height:   Plot width in pixels. (defaulf=40)
    style:    Plot style: "lines", "bars", "cbars" or "heatmap". (default="lines")

Instance Methods | [hide private]
__init__(self, max_v, min_v, center_v, width=200, height=40, style=`'``lines``'`, colorscheme=2) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
update_pixmap(self) | source code
get_color_gradient(self) | source code
draw_bar_profile(self) | source code
draw_centered_bar_profile(self) | source code
draw_line_profile(self) | source code
draw_heatmap_profile(self) | source code
fit_to_scale(self, v) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`
Inherited from Face
_height(self) | source code
_size(self) | source code
_width(self) | source code
load_pixmap_from_file(self, filename) | source code

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, max_v, min_v, center_v, width=200, height=40, style=`'``lines``'`, colorscheme=2) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### update_pixmap(self) | source code
Overrides: Face.update_pixmap